diff --git a/indra/llimage/llimagefilter.h b/indra/llimage/llimagefilter.h
index e392d3215e7b337657d9296b54fd169875d54dd2..d2650c253934320c489a73bddd15e9c5c27b5fb0 100755
--- a/indra/llimage/llimagefilter.h
+++ b/indra/llimage/llimagefilter.h
@@ -38,7 +38,7 @@ typedef enum e_stencil_blend_mode
 {
 	STENCIL_BLEND_MODE_BLEND = 0,
 	STENCIL_BLEND_MODE_ADD   = 1,
-	STENCIL_BLEND_MODE_DODGE = 2,
+	STENCIL_BLEND_MODE_ABACK = 2,
 	STENCIL_BLEND_MODE_FADE  = 3
 } EStencilBlendMode;
diff --git a/indra/llimage/llimagefilter.cpp b/indra/llimage/llimagefilter.cpp
index e0dae9fab2f62f500bf8c2403db993e30a20df9f..7734b08c188d4d46520dcf20789da6da074cd39f 100755
--- a/indra/llimage/llimagefilter.cpp
+++ b/indra/llimage/llimagefilter.cpp
@@ -134,9 +134,9 @@ void LLImageFilter::executeFilter(LLPointer<LLImageRaw> raw_image)
             {
                 mode = STENCIL_BLEND_MODE_ADD;
             }
-            else if (filter_mode == "dodge")
+            else if (filter_mode == "add_back")
             {
-                mode = STENCIL_BLEND_MODE_DODGE;
+                mode = STENCIL_BLEND_MODE_ABACK;
             }
             else if (filter_mode == "fade")
             {
@@ -273,8 +273,8 @@ void LLImageFilter::blendStencil(F32 alpha, U8* pixel, U8 red, U8 green, U8 blue
             pixel[VGREEN] = llclampb(pixel[VGREEN] + alpha * green);
             pixel[VBLUE]  = llclampb(pixel[VBLUE]  + alpha * blue);
             break;
-        case STENCIL_BLEND_MODE_DODGE:
-            // Dodge/burn the incoming color onto the background image
+        case STENCIL_BLEND_MODE_ABACK:
+            // Add back background image to the incoming color
             pixel[VRED]   = llclampb(inv_alpha * pixel[VRED]   + red);
             pixel[VGREEN] = llclampb(inv_alpha * pixel[VGREEN] + green);
             pixel[VBLUE]  = llclampb(inv_alpha * pixel[VBLUE]  + blue);